module.exports = defineTest({
	description: 'single (default) exports',
	options: { output: { name: 'myBundle' } }
});
